@@ -75,6 +75,10 @@ class TwitterUser(models.Model):
     userinfo_json = models.TextField(blank=True)
     objects = TwitterUserManager()
 
+    def __init__(self, *args, **kwargs):
+        super(TwitterUser, self).__init__(*args, **kwargs)
+        self._api = None
+
     def __unicode__(self):
         return self.userinfo().screen_name
 
@@ -96,6 +100,11 @@ class TwitterUser(models.Model):
             self.access_token = access_token
             return True
 
+    def api(self):
+        if self._api is None:
+            self._api = TwitterApi(self.access_token)
+        return self._api
+
     def userinfo(self):
         if self.userinfo_json:
             userinfo_dict = simplejson.loads(self.userinfo_json)
@@ -106,7 +115,7 @@ class TwitterUser(models.Model):
 
     def update_userinfo(self, userinfo=None):
         if userinfo is None:
-            userinfo = get_user_info(self.access_token)
+            userinfo = self.api().GetUserInfo()
         userinfo_json = userinfo.AsJsonString()
         if self.userinfo_json != userinfo_json:
             self.userinfo_json = userinfo_json
@@ -115,12 +124,22 @@ class TwitterUser(models.Model):
     def get_screen_name(self):
         return self.userinfo().screen_name
 
-    def get_friends(self):
-        friends = TwitterApi(self.access_token).GetFriends(cursor=None)
-        return self.objects.filter(twitter_id__in=[f.id for f in friends])
-
-    def get_followers(self):
-        followers = TwitterApi(self.access_token).GetFollowers(cursor=None)
-        return self.objects.filter(twitter_id__in=[f.id for f in followers])
-    
     screen_name = property(get_screen_name)
+
+    def get_site_friends(self, user=None):
+        """
+        Returns a queryset of Users who are Twitter friends of `user`.
+
+        If `user` is None, default to this User.
+        """
+        friends = self.api().GetFriends(user=user, cursor=None)
+        return self.__class__.objects.filter(
+            twitter_id__in=[f.id for f in friends]
+        )
+
+    def get_site_followers(self):
+        """Returns a queryset of Users who are Twitter followers of this User."""
+        followers = self.api().GetFollowers(cursor=None)
+        return self.__class__.objects.filter(
+            twitter_id__in=[f.id for f in followers]
+        )
